@@ -10,7 +10,7 @@ from botocore.client import Config
 from kubernetes import client
 
 from bentoutils.kubeutil import from_yaml, delete_from_yaml
-from bentoutils.print_kaniko_manifest import camel_to_kebab, gen_manifest as gen_kaniko_manifest
+from bentoutils.print_kaniko_manifest import camel_to_kebab, gen_manifest as gen_kaniko_manifest, gen_docker_manifest
 from bentoutils.print_knative_manifest import gen_manifest as gen_knative_manifest
 from bentoutils.print_route_manifest import gen_manifest as gen_route_manifest
 
@@ -191,8 +191,9 @@ def get_pod_name(bento):
 @click.option('--registry', help="private registry in 'host:port' format")
 @click.option('--s3_endpoint', help="S3 endpoint URL", default=None)
 @click.option('--insecure', is_flag=True, help='do not use SSL')
+@click.option('--isdockerconfig', is_flag=True, help='use docker config format')
 @click.option('--uid', help="unique ID")
-def get_kaniko_manifest(bento, path, registry, s3_endpoint, insecure=False, uid=None, silent=False):
+def get_kaniko_manifest(bento, path, registry, s3_endpoint, insecure=False, isdockerconfig=False, uid=None, silent=False):
     if ':' in bento:
         name, version = bento.split(':')
     else:
@@ -204,7 +205,10 @@ def get_kaniko_manifest(bento, path, registry, s3_endpoint, insecure=False, uid=
 
     image_name = camel_to_kebab(name)
     pod_name = '{}-{}'.format(image_name, uid)
-    manifest = gen_kaniko_manifest(name, pod_name, image_name, version, path, registry=registry, s3_endpoint=s3_endpoint, insecure=insecure)
+    if isdockerconfig:
+        manifest = gen_docker_manifest(name, pod_name, image_name, version, path, registry=registry, s3_endpoint=s3_endpoint, insecure=insecure)
+    else:
+        manifest = gen_kaniko_manifest(name, pod_name, image_name, version, path, registry=registry, s3_endpoint=s3_endpoint, insecure=insecure)
     if not silent: click.echo(manifest)
     return manifest, pod_name
 
@@ -212,7 +216,8 @@ def get_kaniko_manifest(bento, path, registry, s3_endpoint, insecure=False, uid=
 @click.command()
 @click.option('--bento', help="bento name in 'name:version' format")
 @click.option('--registry', help="private registry in 'host:port' format")
-def get_knative_manifest(bento, registry):
+@click.option('--selector', help='comma separated list of key=val pairs')
+def get_knative_manifest(bento, registry, selector=None):
     if ':' in bento:
         name, version = bento.split(':')
     else:
@@ -220,7 +225,10 @@ def get_knative_manifest(bento, registry):
         version = 'latest'
 
     pod_name = camel_to_kebab(name)
-    manifest = gen_knative_manifest(pod_name, version, registry)
+    if selector is not None:
+        selector = convert_labels(selector)
+
+    manifest = gen_knative_manifest(pod_name, version, registry, selector)
     click.echo(manifest)
     return manifest
 
@@ -286,10 +294,12 @@ def first_bento_with_label(labels):
 @click.option('--registry', help="private registry in 'host:port' format")
 @click.option('--s3_endpoint', help="S3 endpoint URL", default=None)
 @click.option('--insecure', is_flag=True, help='do not use SSL')
+@click.option('--isdockerconfig', is_flag=True, help='use docker config format')
 @click.pass_context
-def containerize(ctx, bento, registry, s3_endpoint, insecure=False):
+def containerize(ctx, bento, registry, s3_endpoint, insecure=False, isdockerconfig=False):
     path = ctx.invoke(get_saved_path, bento=bento, silent=True)
-    manifest, pod_name = ctx.invoke(get_kaniko_manifest, bento=bento, path=path, registry=registry, s3_endpoint=s3_endpoint, insecure=insecure, silent=True)
+    manifest, pod_name = ctx.invoke(get_kaniko_manifest, bento=bento, path=path, registry=registry, s3_endpoint=s3_endpoint, insecure=insecure, isdockerconfig=isdockerconfig, silent=True)
+    print(manifest)
     from_yaml(manifest)
     click.echo(pod_name)
     return pod_name
@@ -299,20 +309,22 @@ def containerize(ctx, bento, registry, s3_endpoint, insecure=False):
 @click.option('--bento', help="bento name in 'name:version' format")
 @click.option('--pod', help="pod name")
 @click.option('--registry', help="private registry in 'host:port' format")
+@click.option('--isdockerconfig', is_flag=True, help='use docker config format')
 @click.pass_context
-def delete_containerize_job(ctx, bento, pod, registry):
+def delete_containerize_job(ctx, bento, pod, registry, isdockerconfig=False):
     path = ctx.invoke(get_saved_path, bento=bento)
     uid = pod.split('-')[-1]
-    manifest, pod_name = ctx.invoke(get_kaniko_manifest, bento=bento, path=path, registry=registry, uid=uid)
+    manifest, pod_name = ctx.invoke(get_kaniko_manifest, bento=bento, path=path, registry=registry, isdockerconfig=isdockerconfig, uid=uid)
     delete_from_yaml(manifest)
 
 
 @click.command()
 @click.option('--bento', help='bento service name')
 @click.option('--registry', help='registry name')
+@click.option('--selector', help='comma separated list of key=val pairs')
 @click.pass_context
-def deploy_to_knative(ctx, bento, registry):
-    manifest = ctx.invoke(get_knative_manifest, bento=bento, registry=registry)
+def deploy_to_knative(ctx, bento, registry, selector=None):
+    manifest = ctx.invoke(get_knative_manifest, bento=bento, registry=registry, selector=selector)
     from_yaml(manifest)
 
     # Build Docker image
